@@ -207,7 +207,7 @@ void     meta_screen_unshow_desktop      (MetaScreen *screen);
 /* Update whether the destkop is being shown for the current active_workspace */
 void     meta_screen_update_showing_desktop_hint          (MetaScreen *screen);
 
-void     meta_screen_apply_startup_properties (MetaScreen *screen,
+gboolean meta_screen_apply_startup_properties (MetaScreen *screen,
                                                MetaWindow *window);
 void	 meta_screen_composite_all_windows (MetaScreen *screen);
 
